@@ -16,7 +16,7 @@ SEXP RdimY, RdimX, Rdimo, Rdimb, RdimZ, Rdimu, RdimY2, RdimX2, Rdimb2;
 double *betaX, *Yobs, *Ymiss, *mumiss, *omegadrawmiss, *betamiss, *betaobs, *omegaoo, *omegamo, *omegamm, *invomega, *invomega2, *help, *help2, *help3, *imp,*imp2, *zi;
 double *sumzy, *incrzz, *incrzy, *mu, *mu2, *newbeta, *newomega, *sumzi, *yi, *invomega3, *help4, *help5, *help6, *missing, *fixomega,meanom,sdom, *resid, logLH, newlogLH,detom;
 double maxx,maxim,maxim2, *sumxy, *sumxi, *uj, *xi, *ziu, *incrxx, *incrxy, *newu, *mu3,  *mu4, *help7, *help8, *help9, *invomega4, *newomega2,*missing2, *Y2red, *X2red;
-double *covu1, *covu2, *covu12, *fixomega2;
+double *covu1, *covu2, *covu12, *fixomega2, *Y2impred;
 /* Protecting R objects from garbage collection and saving matrices dimensions*/ 
 
 RdimY=PROTECT(getAttrib(Yimp,R_DimSymbol));
@@ -123,6 +123,7 @@ newomega2 = ( double * ) R_alloc ( Ju*Ju , sizeof ( double ) );
 betaX=( double * ) R_alloc ( JYm, sizeof ( double ) );
 imp=( double * ) R_alloc ( IY * JY,sizeof ( double ) );
 imp2=( double * ) R_alloc ( Iu * JY2,sizeof ( double ) );
+Y2impred=( double * ) R_alloc ( Iu * JY2,sizeof ( double ) );
 Y2red=( double * ) R_alloc ( Iu * JY2,sizeof ( double ) );
 X2red=( double * ) R_alloc ( Iu * JX2,sizeof ( double ) );
 resid=( double * ) R_alloc ( IY * JY,sizeof ( double ) );
@@ -166,7 +167,10 @@ for (i=0;i<Iu;i++) {
 	j=0;
 	while (indic==0) {
 		if (INTEGER(clus)[j]==i) {
-			for (k=0;k<JY2;k++) imp2[i+Iu*k]=REAL(Y2imp2)[j+k*IY2];
+			for (k=0;k<JY2;k++) {
+					imp2[i+Iu*k]=REAL(Y2imp2)[j+k*IY2];
+					Y2impred[i+Iu*k]=REAL(Y2imp)[j+k*IY2];
+				}
 			for (k=0;k<(ncon2+ncat2);k++) Y2red[i+Iu*k]=REAL(Y2)[j+k*IY2];
 			for (k=0;k<JX2;k++) X2red[i+Iu*k]=REAL(X2)[j+k*IX2];
 			indic++;
@@ -177,7 +181,7 @@ for (i=0;i<Iu;i++) {
 for (j=0; j<Iu; j++) {
 	missing2[j]=0;
 	for (k=0;k<JY2;k++) {
-		if (ISNAN(imp2[j+k*Iu])) {
+		if (ISNAN(Y2impred[j+k*Iu])) {
 			missing2[j]++;
 		}
 	}
@@ -875,7 +879,7 @@ for (i=0;i<ns;i++) {
 		nmiss=missing2[j];
 		if (nmiss>0) {
 			for (k=0;k<JY2;k++) {
-				if (ISNAN(Y2red[j+k*Iu])) {
+				if (ISNAN(Y2impred[j+k*Iu])) {
 					betamiss[countm]=betaX[k];
 					countm++;
 				}
@@ -885,16 +889,16 @@ for (i=0;i<ns;i++) {
 					counto++;
 				}
 				for (t=0;t<JY2;t++) {
-					if (ISNAN(Y2red[j+k*Iu])&ISNAN(Y2red[j+t*Iu])) {
-						omegamm[countmm]=REAL(covu)[(JY*JZ+k)+(JY*JZ+t*Ju)];
+					if (ISNAN(Y2impred[j+k*Iu])&ISNAN(Y2impred[j+t*Iu])) {
+						omegamm[countmm]=REAL(covu)[(JY*JZ+k)+(JY*JZ+t)*Ju];
 						countmm++;
 					}
-					else if (ISNAN(Y2red[j+t*Iu])) {
-						omegamo[countmo]=REAL(covu)[(JY*JZ+k)+(JY*JZ+t*Ju)];
+					else if (ISNAN(Y2impred[j+t*Iu])) {
+						omegamo[countmo]=REAL(covu)[(JY*JZ+k)+(JY*JZ+t)*Ju];
 						countmo++;	
 					}
-					else if (!ISNAN(Y2red[j+k*Iu])&!ISNAN(Y2red[j+t*Iu])){
-						omegaoo[countoo]=REAL(covu)[(JY*JZ+k)+(JY*JZ+t*Ju)];
+					else if (!ISNAN(Y2impred[j+k*Iu])&!ISNAN(Y2impred[j+t*Iu])){
+						omegaoo[countoo]=REAL(covu)[(JY*JZ+k)+(JY*JZ+t)*Ju];
 						countoo++;	
 					}
 				}
@@ -914,7 +918,7 @@ for (i=0;i<ns;i++) {
 			r8vec_multinormal_sample(nmiss,mumiss,help9,Ymiss,help6,0);
 			countm=0;
 			for (k=0;k<JY2;k++) {
-				if (ISNAN(Y2red[j+k*Iu])) {
+				if (ISNAN(Y2impred[j+k*Iu])) {
 					imp2[j+k*Iu]=Ymiss[countm];
 					countm++;	
 				}	
